@@ -82,7 +82,10 @@ def setup(settings):
 """
 import os
 from logging.config import dictConfig
+from logging.handlers import TimedRotatingFileHandler
+from logging import StreamHandler
 
+from jsonformatter import JsonFormatter
 from . import dictutils
 
 file_handler_backupCount = 30
@@ -92,30 +95,23 @@ def get_console_handler(formatter:str = "default", loglevel:str="DEBUG") -> dict
     """
     return {
         "level": loglevel,
-        "class": "logging.StreamHandler",
+        "class": ".".join([StreamHandler.__module__, StreamHandler.__name__]),
         "formatter": formatter,
     }
 
 def get_file_handler(filename:str, formatter:str="default", loglevel:str="DEBUG") -> dict:
     """Make a file handler settings.
     """
-    if os.name == "nt":
-        return {
-            "level": loglevel,
-            "class": "logging.FileHandler",
-            "filename": filename,
-            "formatter": formatter,
-        }
-    else:
-        return  {
-            "level": loglevel,
-            "class": "logging.handlers.TimedRotatingFileHandler",
-            "filename": filename,
-            "when": "midnight",
-            "interval": 1,
-            "backupCount": file_handler_backupCount,
-            "formatter": formatter,
-        }
+    return  {
+        "level": loglevel,
+        "class": ".".join([TimedRotatingFileHandler.__module__, TimedRotatingFileHandler.__name__]),
+        "filename": filename,
+        "when": "midnight",
+        "interval": 1,
+        "backupCount": file_handler_backupCount,
+        "formatter": formatter,
+        "encoding": "utf-8",
+    }
 
 def get_simple_config(logfile:str=None, loglevel:str=None, logfmt:str=None, loggers:dict=None, logging:dict=None, **kwargs) -> dict:
     """Make simple logging settings.
@@ -150,7 +146,7 @@ def get_simple_config(logfile:str=None, loglevel:str=None, logfmt:str=None, logg
                 "style": "{",
             },
             "json": {
-                "class": "jsonformatter.JsonFormatter",
+                "class": ".".join([JsonFormatter.__module__, JsonFormatter.__name__]),
                 "format": {
                     "asctime": "asctime",
                     "levelname": "levelname",
